//Step 1
php artisan make:migration add_parent_id_column_to_project_categories

	public function up()
	{
		Schema::table('service_categories', function (Blueprint $table) {
			$table->unsignedBigInteger('parent_id')->nullable();
		});
	}
		
	public function down()
	{
		Schema::table('service_categories', function (Blueprint $table) {
			$table->dropColumn('parent_id');
		});
	}

//Step 2
php artisan migrate

//Step 3
Add Trait -> App/Models/ProjectCategory.php

	use Staudenmeir\LaravelAdjacencyList\Eloquent\HasRecursiveRelationships;
	/**.....
	 * .....
	 * @method static tree()
	 */
	class ProjectCategory extends Model
	{
		//nested
		use HasRecursiveRelationships;
		.
		.
		.
	}
	

//Step 4
php artisan make:controller Admin/ProjectCategoriesNestedController

	 /**
     * Display a nested listing of the resource.
     *
     * @return array|Factory|View
     * @throws AuthorizationException
     */
    public function index()
    {
        $this->authorize('admin.project-category.show');

        $data = ProjectCategory::tree()
            ->orderby('order_column')
            ->select('id','title','slug','enabled','parent_id','depth','path')
            ->get()
            ->makeHidden('resource_url')
            ->toTree();

        return view('admin.project-category.nested-listing', compact('data'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @return Response|RedirectResponse
     * @throws AuthorizationException
     */
    public function update(Request $request)
    {
        $this->authorize('admin.project-category.edit');

        DB::transaction(static function () use ($request) {
            collect($request->data)
                ->chunk(100)
                ->each(static function ($bulkChunk) {
                    foreach ($bulkChunk as $k => $item) {
                        ProjectCategory::where('id', $item['id'])
                            ->update(['parent_id' => (isset($item['parent_id']) ? $item['parent_id'] : null), 'order_column' => $k+1]);

                        // TODO your code goes here
                    }
                });
        });

        if ($request->ajax()) {
            return response(['title' => trans('admin.nested.operation.success_title'), 'message' => trans('admin.nested.operation.success_message')]);
        }

        return redirect('admin/project-categories');
    }
	
//Step 5
Add Routes -> routes/web.php

    Route::middleware(['auth:' . config('admin-auth.defaults.guard'), 'admin'])->namespace('App\Http\Controllers')->group(function () {
        Route::get('/admin/nested/project-categories', 'Admin\ProjectCategoriesNestedController@index')->name('admin/project-categories-nested');
        Route::post('/admin/update-nested/project-categories', 'Admin\ProjectCategoriesNestedController@update')->name('admin/project-categories-nested/update');
    });
	
//Step 6
create blade admin.project-category.nested-listing

	@extends('admin.layout.default')

	@section('title', trans('admin.project.title').': '.trans('admin.nested.title'))

	@section('styles')
		<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/nestable2/1.6.0/jquery.nestable.min.css" integrity="sha512-yOW3WV01iPnrQrlHYlpnfVooIAQl/hujmnCmiM3+u8F/6cCgA3BdFjqQfu8XaOtPilD/yYBJR3Io4PO8QUQKWA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
		<link rel="stylesheet" href="{{ asset('css/libs/nestable2/custom.css') }}" />
	@endsection

	@section('body')
		<div class="row">
			<div class="col-md-12">
				<div class="card">
					<div class="card-header">
						<i class="fa fa-indent"></i>
						<span>{{ trans('admin.project.title') }}: {{ trans('admin.nested.card.title') }}</span>
						<small class="d-inline-block">({{ trans('admin.nested.card.desc') }})</small>
					</div>
					<div class="card-block">
						<div class="nested-list">
							<div id="nestable-menu" class="form-group btn-group-sm">
								<button type="button" data-action="expand-all" class="btn btn-outline-success rounded-pill">? {{ trans('admin.nested.actions.expand_all') }}</button>
								<button type="button" data-action="collapse-all" class="btn btn-outline-danger rounded-pill">? {{ trans('admin.nested.actions.collapse_all') }}</button>
							</div>
							<div class="dd" id="nestable"></div>
						</div>
						<div class="form-group mt-5">
							<a href="{{ route('admin/project-categories/index') }}" class="btn btn-outline-secondary text-primary mx-2 mt-2">
								<i class="fa fa-chevron-left text-primary mr-1"></i>
								{{ trans('admin.nested.actions.back_categories') }}
							</a>
							<a href="{{ route('admin/project-categories/create')  }}" class="btn btn-primary mx-2 mt-2">
								<i class="fa fa-plus mr-1"></i>
								{{ trans('admin.nested.actions.add_new_category') }}
							</a>
						</div>
					</div>
				</div>
			</div>
		</div>
	@endsection

	@section('bottom-scripts')
		<script type="module" src="https://cdnjs.cloudflare.com/ajax/libs/nestable2/1.6.0/jquery.nestable.min.js" integrity="sha512-7bS2beHr26eBtIOb/82sgllyFc1qMsDcOOkGK3NLrZ34yTbZX8uJi5sE0NNDYFNflwx1TtnDKkEq+k2DCGfb5w==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
		<script>
                var json = @json($data);
                window["json"] = json; // required for module
                var route = [];
                window["route"] = route; // required for module
                route.post = "{{ route('admin/project-categories-nested/update') }}";
                var trans = [];
                window["trans"] = trans; // required for module
                trans.mainCategory = "{{ trans('admin.nested.card.main_category') }}";
		</script>
		<script type="module" src="{{ asset('js/libs/nestable2/custom.js') }}"></script>
	@endsection
	
//Step 7
Add Nav.Link -> resource/view/admin/layout/sidebar.blade.php ::42

	<li class="nav-item"><a class="nav-link pl-4 mb-1 ml-2 {{ request()->routeIs('admin/project-categories/nested') ? 'active' : '' }}" href="{{ url('admin/nested/project-categories') }}"><i class="nav-icon fa fa-indent"></i> {{ trans('admin.nested.title') }}</a></li>

